module.exports = defineTest({
	description: 'deoptimizes return values of class methods'
});
